==> apigeelint-2.44.0.tgz: package/test/specs/PO033-extractVariables-JSON-Variable-type.js <==
/*
  Copyright 2019-2023 Google LLC

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      https://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

/* global describe, it */

const testID = "PO033",
  assert = require("assert"),
  fs = require("fs"),
  util = require("util"),
  path = require("path"),
  bl = require("../../lib/package/bundleLinter.js"),
  plugin = require(bl.resolvePlugin(testID)),
  Policy = require("../../lib/package/Policy.js"),
  Dom = require("@xmldom/xmldom").DOMParser,
  rootDir = path.resolve(__dirname, "../fixtures/resources/PO033"),
  debug = require("debug")(`apigeelint:${testID}-test`);

const loadPolicy = (sourceDir, shortFileName) => {
  const fqPath = path.join(sourceDir, shortFileName),
    policyXml = fs.readFileSync(fqPath).toString("utf-8"),
    doc = new Dom().parseFromString(policyXml),
    p = new Policy(doc.documentElement, this);
  p.getElement = () => doc.documentElement;
  p.fileName = shortFileName;
  return p;
};

describe(`${testID} - policy passes ExtractVariables hygiene check`, function () {
  const sourceDir = path.join(rootDir, "pass");
  const testOne = (shortFileName) => {
    const policy = loadPolicy(sourceDir, shortFileName);
    const policyType = policy.getType();
    it(`check ${shortFileName} passes`, () => {
      assert.notEqual(policyType, undefined, `${policyType} should be defined`);
      plugin.onPolicy(policy, (e, foundIssues) => {
        assert.equal(e, undefined, "should be undefined");
        const messages = policy.getReport().messages;
        debug(`pass ${shortFileName} issues: ${foundIssues}`);
        debug(`pass ${shortFileName} messages: ${util.format(messages)}`);
        assert.equal(foundIssues, false, "should be no issues");
        assert.ok(messages, "messages should exist");
        assert.equal(messages.length, 0, "unexpected number of messages");
      });
    });
  };

  fs.readdirSync(sourceDir)
    .filter((shortFileName) => shortFileName.endsWith(".xml"))
    .forEach(testOne);
});

describe(`${testID} - policy does not ExtractVariables hygiene check`, () => {
  const sourceDir = path.join(rootDir, "fail");
  const expectedErrorMessages = require(path.join(sourceDir, "messages.js"));
  const testOne = (shortFileName) => {
    const policy = loadPolicy(sourceDir, shortFileName);
    const policyType = policy.getType();
    it(`check ${shortFileName} throws error`, () => {
      assert.notEqual(policyType, undefined, `${policyType} should be defined`);
      plugin.onPolicy(policy, (e, foundIssues) => {
        assert.equal(undefined, e, "should be undefined");
        assert.equal(true, foundIssues, "should be issues");
        const messages = policy.getReport().messages;
        assert.ok(messages, "messages should exist");
        //console.log(util.format(messages));
        assert.equal(1, messages.length, "unexpected number of messages");
        assert.ok(messages[0].message, "did not find message member");
        const expected = expectedErrorMessages[policy.fileName];
        assert.ok(
          expected,
          "test configuration failure: did not find an expected message"
        );
        assert.equal(
          expected,
          messages[0].message,
          "did not find expected message"
        );
        debug(`message[0]: ${messages[0].message}`);
      });
    });
  };

  fs.readdirSync(sourceDir)
    .filter((shortFileName) => shortFileName.endsWith(".xml"))
    .forEach(testOne);
});

==> apigeelint-2.46.3.tgz: package/test/specs/PO033-extractVariables-JSON-Variable-type.js <==
/*
  Copyright 2019-2023 Google LLC

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      https://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

/* global describe, it */

const testID = "PO033",
  assert = require("assert"),
  fs = require("fs"),
  util = require("util"),
  path = require("path"),
  bl = require("../../lib/package/bundleLinter.js"),
  plugin = require(bl.resolvePlugin(testID)),
  Policy = require("../../lib/package/Policy.js"),
  Dom = require("@xmldom/xmldom").DOMParser,
  rootDir = path.resolve(__dirname, "../fixtures/resources/PO033"),
  debug = require("debug")(`apigeelint:${testID}-test`);

const loadPolicy = (sourceDir, shortFileName) => {
  const fqPath = path.join(sourceDir, shortFileName),
    policyXml = fs.readFileSync(fqPath).toString("utf-8"),
    doc = new Dom().parseFromString(policyXml),
    p = new Policy(doc.documentElement, this);
  p.getElement = () => doc.documentElement;
  p.fileName = shortFileName;
  return p;
};

describe(`${testID} - policy passes ExtractVariables hygiene check`, function () {
  const sourceDir = path.join(rootDir, "pass");
  const testOne = (shortFileName) => {
    const policy = loadPolicy(sourceDir, shortFileName);
    const policyType = policy.getType();
    it(`check ${shortFileName} passes`, () => {
      assert.notEqual(policyType, undefined, `${policyType} should be defined`);
      plugin.onPolicy(policy, (e, foundIssues) => {
        assert.equal(e, undefined, "should be undefined");
        const messages = policy.getReport().messages;
        debug(`pass ${shortFileName} issues: ${foundIssues}`);
        debug(`pass ${shortFileName} messages: ${util.format(messages)}`);
        assert.equal(foundIssues, false, "should be no issues");
        assert.ok(messages, "messages should exist");
        assert.equal(messages.length, 0, "unexpected number of messages");
      });
    });
  };

  fs.readdirSync(sourceDir)
    .filter((shortFileName) => shortFileName.endsWith(".xml"))
    .forEach(testOne);
});

describe(`${testID} - policy does not pass ExtractVariables hygiene check`, () => {
  const sourceDir = path.join(rootDir, "fail");
  const expectedErrorMessages = require(path.join(sourceDir, "messages.js"));
  const testOne = (shortFileName) => {
    const policy = loadPolicy(sourceDir, shortFileName);
    const policyType = policy.getType();
    it(`check ${shortFileName} throws error`, () => {
      assert.notEqual(policyType, undefined, `${policyType} should be defined`);
      plugin.onPolicy(policy, (e, foundIssues) => {
        assert.equal(undefined, e, "should be undefined");
        assert.equal(true, foundIssues, "should be issues");
        const messages = policy.getReport().messages;
        assert.ok(messages, "messages should exist");
        //console.log(util.format(messages));
        assert.equal(1, messages.length, "unexpected number of messages");
        assert.ok(messages[0].message, "did not find message member");
        const expected = expectedErrorMessages[policy.fileName];
        assert.ok(
          expected,
          "test configuration failure: did not find an expected message"
        );
        assert.equal(
          expected,
          messages[0].message,
          "did not find expected message"
        );
        debug(`message[0]: ${messages[0].message}`);
      });
    });
  };

  fs.readdirSync(sourceDir)
    .filter((shortFileName) => shortFileName.endsWith(".xml"))
    .forEach(testOne);
});
